/*
    FEARLUS model1-0: AbstractGovernment.h
    Copyright (C) 1999-2006  Macaulay Institute

    This file is part of FEARLUS model1-0, an agent-based model of land use
    change.

    FEARLUS model1-0 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    FEARLUS model1-0 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. (LICENCE file in
    this directory.)

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Contact information:
      Gary Polhill,
      Macaulay Institute, Craigiebuckler, Aberdeen, AB15 8QH. United Kingdom
      g.polhill@macaulay.ac.uk
*/

/* The Government agent is introduced in Model 0-8 to monitor the
 * pollution from the land uses and to create incentives that keep
 * pollution to a minimum. This abstract class is one that all
 * Government agents should subclass from. Each class of government is
 * expected to have its own parameter file and corresponding
 * format. All the model has as parameters are the class of Government
 * agent to use and the name of the file to load government parameters
 * from. The government class is responsible for looking after the
 * loading and printing of parameters. This means subclasses will have
 * to use class variables for storing them.
 */


#import "FearlusThing.h"
#import <stdio.h>

@class LandAllocator, Environment, Parameter;

@interface AbstractGovernment: FearlusThing {
  LandAllocator *landAllocator;
  Environment *env;
  Parameter *parameter;
}

+(void)writeParameters: (FILE *)fp;
				// Override this method to write the parameters
				// to a file
+(void)loadParameters: (char *)filename;
				// Override this method to load the parameters
				// in using the class-specific file format
-(void)setParameters: (Parameter *)p
         environment: (Environment *)e
           allocator: (LandAllocator *)la;
-configure;			// Override this method to initialise
-(void)govern;			// This is the method called from the schedule
				// -- override it to implement the behaviour
				// you require for the Government

@end
