/*
    FEARLUS model1-0: AbstractGovernment.m
    Copyright (C) 1999-2006  Macaulay Institute

    This file is part of FEARLUS model1-0, an agent-based model of land use
    change.

    FEARLUS model1-0 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    FEARLUS model1-0 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. (LICENCE file in
    this directory.)

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Contact information:
      Gary Polhill,
      Macaulay Institute, Craigiebuckler, Aberdeen, AB15 8QH. United Kingdom
      g.polhill@macaulay.ac.uk
*/

/* Implementation of the AbstractGovernment class. Some discussion of
 * how calls to this class are handled is required. The only method it
 * is an error to call in this class is -govern. For the other methods
 * it is conceivable that a very simple government class could have no
 * parameters and thus nothing to configure, meaning that such a class
 * need not implement the methods concerned with government
 * parameters, and their default action is correctly to do
 * nothing. The first time at which it will be detected that
 * AbstractGovernment has been wrongly specified in the parameter file
 * as the government class to use will be when the -govern method is
 * called.
 */

#import "AbstractGovernment.h"
#import <stdlib.h>

@implementation AbstractGovernment

/* +writeParameters: 
 *
 * There aren't any parameters to write for the abstract government
 * class. This method does nothing therefore.
 */

+(void)writeParameters: (FILE *)fp {
}

/* +loadParameters:
 *
 * The AbstractGovernment class has no parameters to use. This method
 * does nothing.
 */

+(void)loadParameters: (char *)filename {
}

/* setParameters:environment:allocator: -> self
 *
 * A method allowing parameters, environment and the land allocator to
 * be passed in to a government instance.
 */

-(void)setParameters: (Parameter *)p
	 environment: (Environment *)e
	   allocator: (LandAllocator *)la {
  parameter = p;
  landAllocator = la;
  env = e;
}

/* configure -> self
 *
 * A method allowing the government object to configure itself. As an
 * abstract government class, there is nothing for this method to
 * configure, so it does nothing.
 */

-configure {
  return self;
}

/* govern
 *
 * A method for describing the behaviour of the government class. This
 * method must get overridden by subclasses. It is an error for it to
 * get called.
 */

-(void)govern {
  fprintf(stderr, "Error: The -govern method of an instance of "
	  "AbstractGovernment has been called. This is probably because "
	  "AbstractGovernment has been given as the government class "
	  "parameter. If so, then note that AbstractGovernment is not a "
	  "valid entry for this parameter.\n");
  abort();
}

@end
