/*
    FEARLUS model1-0: AbstractSelectionStrategy.m
    Copyright (C) 1999-2006  Macaulay Institute

    This file is part of FEARLUS model1-0, an agent-based model of land use
    change.

    FEARLUS model1-0 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    FEARLUS model1-0 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. (LICENCE file in
    this directory.)

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Contact information:
      Gary Polhill,
      Macaulay Institute, Craigiebuckler, Aberdeen, AB15 8QH. United Kingdom
      g.polhill@macaulay.ac.uk
*/
/*

Implementation of AbstractSelectionStrategy class

*/

#import "AbstractSelectionStrategy.h"
#import "AbstractLandManager.h"
#import "Parameter.h"
#import "AssocArray.h"
#import <stdlib.h>

@implementation AbstractSelectionStrategy

/* +create:manager:parameters:
 *
 * Create a new AbstractSelectionStrategy.
 */

+create: z manager: (AbstractLandManager *)mgr parameters: (Parameter *)p {
  AbstractSelectionStrategy *obj = [super create: z];

  obj->lm = mgr;
  obj->parameter = p;

  return obj;
}

/* -newBiddingRound
 *
 * Allow the possibility of preprocessing at the beginning of each bidding
 * round. Here we get the budget.
 */

-(void)newBiddingRound {
  budget = [lm getLandParcelBudget];
}

/* -selectBids:fromList:
 *
 * Abort, as this method must be overridden.
 */

-(void)selectBids: (AssocArray *)bids fromList: (id <List>)list {
  fprintf(stderr,
	  "-selectBids:fromList: called in AbstractSelectionStrategy\n");
  abort();
}

@end
