/*
    FEARLUS model1-0: LTSymbol.m
    Copyright (C) 1999-2006  Macaulay Institute

    This file is part of FEARLUS model1-0, an agent-based model of land use
    change.

    FEARLUS model1-0 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    FEARLUS model1-0 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. (LICENCE file in
    this directory.)

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Contact information:
      Gary Polhill,
      Macaulay Institute, Craigiebuckler, Aberdeen, AB15 8QH. United Kingdom
      g.polhill@macaulay.ac.uk
*/
/*

Implementation of LTSymbol class

*/
#import <errno.h>
#import <string.h>
#import <stdio.h>
#import "LTSubgroup.h"
#import "LTSymbol.h"

@implementation LTSymbol


/* create: subgroup:
 *
 * Create a new symbol in a certain subgroup.
 */

+create: aZone subgroup: (LTSubgroup *)subgp {
  static int counter = 1;

  LTSymbol *obj = [super create: aZone];

  obj->subgroup = subgp;
  obj->pin = counter;

  counter++;
  return obj;
}

/* -printSymbol:
 *
 * Print the symbol with the specified space indent
 */

-(void)printSymbol: (int)indent {
  int i;

  for(i = 0; i < indent; i++) printf("  ");
  printf("Symbol %s (%d)\n", name, pin);
}

-setName: (char *)n {
  name = n;			// n is assumed to be in this symbol's zone
  return self;
}

-(char *)getName {
  return name;
}

-(LTSubgroup *)getSubgroup {
  return subgroup;
}

-(int)getPin {
  return pin;
}

-(void)drop {
  [[self getZone] free: name];
  [super drop];
}


@end
