/*
    FEARLUS model1-0: LandUseGroupTrigger.h
    Copyright (C) 1999-2006  Macaulay Institute

    This file is part of FEARLUS model1-0, an agent-based model of land use
    change.

    FEARLUS model1-0 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    FEARLUS model1-0 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. (LICENCE file in
    this directory.)

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Contact information:
      Gary Polhill,
      Macaulay Institute, Craigiebuckler, Aberdeen, AB15 8QH. United Kingdom
      g.polhill@macaulay.ac.uk
*/

/* The LandUseGroupTrigger class creates a trigger that can be configured
 * to approve or disapprove of any aspect of a land manager's decision as
 * stored in the land parcels they own. This is achieved by specifying
 * a combination of symbol values in each subgroup of the Land Use group.
 * The value for the landUseSymbols parameter is a comma separated list
 * of subgroup/symbol pairs that collectively form a conjunction. Only one
 * subgroup/symbol pair may appear for each subgroup. The format is
 * subgroup1/symbol1,subgroup2/symbol2, etc. Combining several instances
 * of this class should allow creation of quite sophisticated approval and
 * disapproval rules.
 */

#import "AbstractTrigger.h"

@interface LandUseGroupTrigger: AbstractTrigger {
  int min_subgroup_pin;
  int max_subgroup_pin;
  int *symbol_pins;
  char *land_use_symbols;
}

-(void)load: (FILE *)fp;
-(void)writeParameters: (FILE *)fp;

-(void)manager: (AbstractSocialLandManager *)lm_subj
       ofManager: (AbstractSocialLandManager *)lm_obj
       approves: (double *)app
       disapproves: (double *)disapp;
-(void)drop;

@end
