/*
    FEARLUS model1-0: LandUseStateReport.m
    Copyright (C) 1999-2006  Macaulay Institute

    This file is part of FEARLUS model1-0, an agent-based model of land use
    change.

    FEARLUS model1-0 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    FEARLUS model1-0 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. (LICENCE file in
    this directory.)

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Contact information:
      Gary Polhill,
      Macaulay Institute, Craigiebuckler, Aberdeen, AB15 8QH. United Kingdom
      g.polhill@macaulay.ac.uk
*/
/*


The implementation for the LandUseStateReport object

*/

#import "LandUseStateReport.h"
#import "Parameter.h"
#import "ModelSwarm.h"
#import "FearlusArguments.h"
#import "FearlusOutput.h"
#import "FearlusStream.h"
#import "LTGroupState.h"
#import "Environment.h"
#import "LandUse.h"
#import "Number.h"

@implementation LandUseStateReport

/*

reportForYear:toFile:

Create a report showing the states of each land use in the environment.

Note that [FearlusOutput nl] is used as the string to print for a
new line. This is in case DOS mode has been specified on the command
line.

*/

-(void)reportForYear: (unsigned)year toFile: (FILE *)fp {
  id inx;
  LandUse *lu;
  FearlusStream *stream = [FearlusStream create: scratchZone file: fp];

  // Loop through the land uses and print their states
  for(inx = [[[model getEnvironment] getLandUses] begin: [self getZone]],
	[inx next];
      [inx getLoc] == Member;
      [inx next]) {
    lu = (LandUse *)[inx get];
    fprintf(fp, "Land use\t");
    [lu writeState: stream];
    fprintf(fp, "%s", [FearlusOutput nl]);
  }
  [inx drop];
  [stream dropNotClose];
}


@end

