/*
    FEARLUS model1-0: ObserverSwarm.h
    Copyright (C) 1999-2006  Macaulay Institute

    This file is part of FEARLUS model1-0, an agent-based model of land use
    change.

    FEARLUS model1-0 is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    FEARLUS model1-0 is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details. (LICENCE file in
    this directory.)

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Contact information:
      Gary Polhill,
      Macaulay Institute, Craigiebuckler, Aberdeen, AB15 8QH. United Kingdom
      g.polhill@macaulay.ac.uk
*/
/*


Interface for the ObserverSwarm class -- a swarm for probing and graphing and
displaying the model swarm. This is based very heavily on the tutorial
ObserverSwarm class.

*/

#import <swarm.h>

#ifndef DISABLE_GUI

#import <simtoolsgui/GUISwarm.h>
#import <space/Object2dDisplay.h>
#import <simtoolsgui.h>
#import <collections.h>
#import <objectbase.h>
#import <analysis.h>
#import <gui.h>
#import <tkobjc/CheckButton.h>
#import <tkobjc/Colormap.h>
#import <tkobjc/global.h>
#import <activity.h>
#import <sys/types.h>
#import <sys/stat.h>
#import <errno.h>
#import <string.h>
#import <objc/objc-api.h>	// sel_get_name

#define BLANK_CELL_CIX 251
#define NA_CELL_CIX 252
#define BLACK_CIX 253
#define WHITE_CIX 254
#define BLANK_CELL_COL "Black"
#define NA_CELL_COL "Gold"
#define BLACK_COL "Black"
#define WHITE_COL "White"

@class ModelSwarm, EZBar, DBColormap, Parameter, Reporter, StrategyColourKey;

@interface ObserverSwarm: GUISwarm {
  int displayFrequency;
  // Maybe there should be some variables for handling which displays to do
  Parameter *parameter;
  Reporter *reporter;
  unsigned seed;

  id displayActions;
  id displaySchedule;
  id initialSchedule;
  id reporterSchedule;

  ModelSwarm *modelSwarm;

  BOOL showStrategyColourKey;
  BOOL showUseRaster;
  BOOL showSuitabilityRaster;
  BOOL showProfitabilityRaster;
  BOOL showBiophysRaster;
  BOOL showManagerRaster;
  BOOL showSubPopRaster;
  BOOL showStrategyRaster;
  BOOL showUseChangeRaster;
  BOOL showManagerChangeRaster;
  BOOL showPriceRankRaster;
  BOOL showTotalPriceRankRaster;
  BOOL showAveragePriceRankRaster;

  BOOL showParcelBoundaries;
  BOOL showManagerBoundaries;

  BOOL showStrategyGraph;
  BOOL showPollutionGraph;
  BOOL showUseMarketGraph;
  BOOL showParcelsOwnedGraph;
  BOOL showYieldGraph;
  BOOL showPopulationGraph;
  BOOL showUseGraph;
  BOOL showSuitabilityGraph;
  BOOL showProfitabilityGraph;
  BOOL showWealthGraph;
  BOOL showDeathGraph;
  BOOL showAgeGraph;
  BOOL showUtilityGraph;
  BOOL showSalienceGraph;
  BOOL showApprovedGraph;
  BOOL showApprovingGraph;
  BOOL showPriceGraph;
  BOOL showNewBidGraph;
  BOOL showBidGraph;

  BOOL showSalienceDist;
  BOOL showManagersDist;
  BOOL showUseBar;
  BOOL showNWeightDist;
  BOOL showThresholdDist;
  BOOL showImitProbDist;

  BOOL showZoneGraph;
  BOOL showObserverZone;
  BOOL showModelZone;
  BOOL showScratchZone;
  BOOL showManagerZone;
  BOOL showCaseZone;
  BOOL showObserverZoneDetail;
  BOOL showModelZoneDetail;
  BOOL showScratchZoneDetail;
  BOOL showManagerZoneDetail;
  BOOL showCaseZoneDetail;

  BOOL saveUseRaster;
  BOOL saveSuitabilityRaster;
  BOOL saveProfitabilityRaster;
  BOOL saveManagerRaster;
  BOOL saveSubPopRaster;
  BOOL saveStrategyRaster;
  BOOL saveUseChangeRaster;
  BOOL saveManagerChangeRaster;
  BOOL savePriceRankRaster;
  BOOL saveTotalPriceRankRaster;
  BOOL saveAveragePriceRankRaster;

  BOOL savePollutionGraph;
  BOOL saveUseGraph;
  BOOL saveSuitabilityGraph;
  BOOL saveProfitabilityGraph;
  BOOL saveWealthGraph;
  BOOL saveDeathGraph;
  BOOL saveAgeGraph;
  BOOL saveUtilityGraph;
  BOOL saveSalienceGraph;
  BOOL savePriceGraph;
  BOOL saveNewBidGraph;
  BOOL saveBidGraph;

  BOOL saveSalienceDist;
  BOOL saveManagersDist;
  BOOL saveUseBar;
  BOOL saveNWeightDist;
  BOOL saveThresholdDist;
  BOOL saveImitProbDist;

  DBColormap *colorMap;
  StrategyColourKey *legend;
  id <Colormap> strategyCMap;
  id <Colormap> greyCMap;

  id <ZoomRaster> useRaster;
  id <ZoomRaster> suitabilityRaster;
  id <ZoomRaster> profitabilityRaster;
  id <ZoomRaster> useChangeRaster;
  id <ZoomRaster> managerChangeRaster;
  id <ZoomRaster> managerRaster;
  id <ZoomRaster> subPopRaster;
  id <ZoomRaster> strategyRaster;
  id <ZoomRaster> biophysRaster;
  id <ZoomRaster> priceRankRaster;
  id <ZoomRaster> totalPriceRankRaster;
  id <ZoomRaster> averagePriceRankRaster;

  id <EZGraph> parcelsOwnedGraph;
  id <EZGraph> yieldGraph;
  id <EZGraph> populationGraph;
  id <EZGraph> useGraph;
  id <EZGraph> suitabilityGraph;
  id <EZGraph> profitabilityGraph;
  id <EZGraph> wealthGraph;
  id <EZGraph> deathGraph;
  id <EZGraph> ageGraph;
  id <EZGraph> pollutionGraph;
  id <EZGraph> useMarketGraph;
  id <EZGraph> salienceGraph;
  id <EZGraph> utilityGraph;
  id <EZGraph> priceGraph;
  id <EZGraph> bidGraph;
  id <EZGraph> newBidGraph;

  id <EZGraph> zoneGraph;

  id <EZBin> managersDist;

  int nHistogramBins;
  int zoomSize;
  int biophysSubgroup;

  id <List> nbrwgtDists;
  id <List> happyThreshDists;
  id <List> imitProbDists;
  id <List> salienceDists;
  id <List> strategyGraphs;
  id <List> approvedGraphs;
  id <List> approvingGraphs;
  id <List> widgetList;

  id <ActionTo> resizeGraphsAction;

  id <Canvas> obsFrame;
  id <CheckButton> testCheck;

  EZBar *useBar;

  id <Object2dDisplay> useChangeDisplay;
  id <Object2dDisplay> suitabilityDisplay;
  id <Object2dDisplay> profitabilityDisplay;
  id <Object2dDisplay> managerChangeDisplay;
  id <Object2dDisplay> useDisplay;
  id <Object2dDisplay> managerDisplay;
  id <Object2dDisplay> subPopDisplay;
  id <Object2dDisplay> strategyDisplay;
  id <Object2dDisplay> parcelNbrDisplay;
  id <Object2dDisplay> biophysDisplay;
  id <Object2dDisplay> priceRankDisplay;
  id <Object2dDisplay> totalPriceRankDisplay;
  id <Object2dDisplay> averagePriceRankDisplay;
}

+createBegin: (id)z;
-createEnd;
-(void)buildGUIObjects;
-buildReporter;
-(void)toggleManagerBoundaries;
-(void)toggleParcelBoundaries;
-(void)ontology;
-buildObjects;
-(double)countScratchZone;
-(double)countCaseZone;
-(double)countManagerZone;
-(double)countObserverZone;
-(double)countModelZone;
-buildActions;
-toggleMgrNeighbourhoodOfX: (int)x Y: (int)y;
-incBiophysSubgroupDisplayed;
-decBiophysSubgroupDisplayed;
-togglePhysNeighbourhoodOfX: (int)x Y: (int)y;
-(void)populateGraphs;
-activateIn: (id)swarmContext;
-(void)setSpecifiedSeed: (unsigned)value;
-(void)drop;

@end

#else

#import "BatchSwarm.h"

@interface ObserverSwarm: BatchSwarm {
}

@end

#endif
